from IzzyLib.misc import DotDict
from sqlalchemy import Column, Integer, String, DateTime, Boolean
from sqlalchemy.ext.declarative import declarative_base


Base = declarative_base()
tables = DotDict()

class Config(Base):
	__tablename__ = 'config'

	id = Column('id', Integer, primary_key=True, autoincrement=True)
	key = Column('key', String, unique=True)
	value = Column('value', String)
	type = Column('type', String, default='str')


	def __repr__(self):
		return f'Config(id={self.id}, key="{self.key}", value="{self.value}", type="{self.type}")'


class Cookie(Base):
	__tablename__ = 'cookie'

	id = Column('id', Integer, primary_key=True, autoincrement=True)
	userid = Column('userid', Integer, nullable=False)
	token = Column('token', String, nullable=False, unique=True)
	access = Column('access', DateTime)
	timestamp = Column('timestamp', DateTime)


	def __repr__(self):
		return f'Cookie(id={self.id}, cookie="{self.cookie}")'


class Domain(Base):
	__tablename__ = 'domain'

	id = Column('id', Integer, primary_key=True, autoincrement=True)
	domain = Column('domain', String, nullable=False, unique=True)
	web_domain = Column('web_domain', String, nullable=False, unique=True)
	name = Column('name', String)
	admin = Column('admin', String)
	description = Column('description', String)
	allow = Column('allow', Boolean, default=False)
	timestamp = Column('timestamp', DateTime)


	def __repr__(self):
		return f'Domain(id={self.id}, domain="{self.domain}", name="{self.name}")'


tables.update({
	'config': Config,
	'cookie': Cookie,
	'domain': Domain
})
