from IzzyLib import logging
from IzzyLib.misc import Path
from datetime import datetime
from sanic import response
from sanic.views import HTTPMethodView

from .config import config
from .database import db
from .functions import Error, GetTheme, Client


async def MastoBase(request, path=None):
	if path:
		filepath = config.mastodon.path.join('public').join(path)

		if filepath.isfile():
			return await response.file(filepath.str())

	else:
		path = '/'

	host = request.headers.get('host', config.mastodon.web_domain)

	masto = Client.request(f'http://{config.mastodon.host}{request.path}',
		headers = request.headers.asDict(),
		method = request.method,
		data = request.data.text
	)

	masto.headers.pop('transfer-encoding', None)

	resp = response.raw(masto.body(False),
		headers = masto.headers.asDict(),
		status = masto.status,
		content_type = masto.headers.get('content-type', 'text/html')
	)

	return resp


async def MastoUser(request, path=None):
	pass


async def MastoStatus(request, path=None):
	pass


class Home(HTTPMethodView):
	async def get(self, request):
		pass


	async def post(self, request):
		pass


class Settings(HTTPMethodView):
	async def get(self, request):
		pass


	async def post(self, request):
		pass


class Instances(HTTPMethodView):
	async def get(self, request, msg=None, error=None):
		pass


	async def post(self, request):
		pass


class Login(HTTPMethodView):
	async def get(self, request, msg=None, error=None):
		data = {
			'msg': msg,
			'error': error,
			'redir': {
				'path': request.data.query.get('redir'),
				'data': request.data.query.get('query')
			}
		}

		return config.template.response('pages/login.haml', request, data)


	async def post(self, request):
		pass


class Logout(HTTPMethodView):
	async def get(self, request):
		pass


class Style(HTTPMethodView):
	async def get(self, request, timestamp=None):
		user_config = request.cookie.user.config if request.cookie.user else {}
		theme = user_config.get('theme', 'pink')
		path = config.frontend.join('style')

		data = {
			'cssfiles': [css for css in path.listdir() if css.str().endswith('css')]
		}
		data.update(GetTheme(theme))

		return config.template.response('style.css', request, data, ctype='text/css')
